#
# spec file for package perl-Email-MIME-Kit
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-Email-MIME-Kit
Version:        3.000005
Release:        1.1
%define cpan_name Email-MIME-Kit
Summary:        Build Messages From Templates
License:        Artistic-1.0 or GPL-1.0+
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/Email-MIME-Kit/
Source0:        http://www.cpan.org/authors/id/R/RJ/RJBS/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Email::MIME) >= 1.930
BuildRequires:  perl(Email::MIME::Creator)
BuildRequires:  perl(Email::MessageID) >= 1.400
BuildRequires:  perl(JSON) >= 2
BuildRequires:  perl(Module::Runtime)
BuildRequires:  perl(Moose) >= 0.65
BuildRequires:  perl(Moose::Role)
BuildRequires:  perl(Moose::Util::TypeConstraints)
BuildRequires:  perl(String::RewritePrefix)
BuildRequires:  perl(Test::Deep)
BuildRequires:  perl(Test::More) >= 0.96
BuildRequires:  perl(YAML::XS)
Requires:       perl(Email::MIME) >= 1.930
Requires:       perl(Email::MIME::Creator)
Requires:       perl(Email::MessageID) >= 1.400
Requires:       perl(JSON) >= 2
Requires:       perl(Module::Runtime)
Requires:       perl(Moose) >= 0.65
Requires:       perl(Moose::Role)
Requires:       perl(Moose::Util::TypeConstraints)
Requires:       perl(String::RewritePrefix)
Requires:       perl(YAML::XS)
%{perl_requires}

%description
Email::MIME::Kit is a templating system for email messages. Instead of
trying to be yet another templating system for chunks of text, it makes it
easy to build complete email messages.

It handles the construction of multipart messages, text and HTML
alternatives, attachments, interpart linking, string encoding, and
parameter validation.

Although nearly every part of Email::MIME::Kit is a replaceable component,
the stock configuration is probably enough for most use. A message kit will
be stored as a directory that might look like this:

  sample.mkit/
    manifest.json
    body.txt
    body.html
    logo.jpg

The manifest file tells Email::MIME::Kit how to put it all together, and
might look something like this:

  {
    "renderer": "TT",
    "header": [
      { "From": "WY Corp <noreplies@wy.example.com>" },
      { "Subject": "Welcome aboard, [% recruit.name %]!" }
    ],
    "alternatives": [
      { "type": "text/plain", "path": "body.txt" },
      {
        "type": "text/html",
        "path": "body.html",
        "container_type": "multipart/related",
        "attachments": [ { "type": "image/jpeg", "path": "logo.jpg" } ]
      }
    ]
  }

*Please note:* the assembly of HTML documents as multipart/related bodies
may be simplified with an alternate assembler in the future.

The above manifest would build a multipart alternative message. GUI mail
clients would see a rendered HTML document with the logo graphic visible
from the attachment. Text mail clients would see the plaintext.

Both the HTML and text parts would be rendered using the named renderer,
which here is Template-Toolkit.

The message would be assembled and returned as an Email::MIME object, just
as easily as suggested in the SYNOPSIS above.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes LICENSE README

%changelog
* Wed Sep 21 2016 coolo@suse.com
- updated to 3.000005
  see /usr/share/doc/packages/perl-Email-MIME-Kit/Changes
  3.000005  2016-09-20 11:22:25-04:00 America/New_York
  - set up kit_reader and manifest_reader with a helper attribute instead
    of the weird and rarely-seen Moose "initializer" system
* Fri Aug  5 2016 coolo@suse.com
- updated to 3.000004
  see /usr/share/doc/packages/perl-Email-MIME-Kit/Changes
  3.000004  2016-08-03 22:48:27-04:00 America/New_York
  - require a newer Email::MIME so we can rely on the header_raw method
  3.000003  2016-08-03 09:08:35-04:00 America/New_York
  - manifest.json is now properly decoded while being read, so
    UTF-8 strings in the manifest.json are treated the same way as
    \u.... sequences.  If you had been doubly-UTF-8-encoding your
    manifest.json to work around this bug, your code is now broken
    because my code is now fixed.
* Mon Apr 13 2015 coolo@suse.com
- updated to 3.000002
  see /usr/share/doc/packages/perl-Email-MIME-Kit/Changes
  3.000002  2015-02-19 11:02:14-05:00 America/New_York
  - immutabilize more classes
  3.000001  2014-12-01 14:10:12-05:00 America/New_York
    [BREAKING CHANGES]
  - content read from disk (templates, for example) is now decoded
    as UTF-8 if and only if the content type for which it is being used
    is text/*
  - for more information on this change, consult the "ENCODING" section
    of the documentation for Email::MIME::Kit
    [BUG FIXES]
  - non-text parts are no longer padded with CRLFs
  2.102015  2014-11-02 08:59:04-05:00 America/New_York
  - read kit entries in binary mode for the sake of Win32 (thanks,
    Octavian Rasnita!)
  2.102014  2014-06-06 08:24:52-04:00 America/New_York
  - break a circular reference in the assembler (thanks, Charlie
    Garrison)
  2.102013  2013-08-12 21:32:01 America/New_York
    update bugtracker and repo
    only call _set_attachment_info when it is present
  2.102012  2013-04-08 15:29:38 America/New_York
    make tests for header encoding less specific: the header must be
    encoded, but we don't mind if it's B or Q
  2.102011  2012-07-25 10:58:12 America/New_York
    stop failing with changed crlf detection
* Mon Jan 17 2011 coolo@novell.com
- initial package 2.102010
  * created by cpanspec 1.78.03
